@@ -1,7 +1,7 @@
 from .bot import Bot, InvokeError
 from .gateway import Gateway, InvokeError
 from .intents import Intents
-from .http_client import Route, HTTPClient
+from .http_client import HTTPClient
 from .embed import Embed
 
-__version__ = "0.1.9"
\ No newline at end of file
+__version__ = "0.2.0"
\ No newline at end of file
