@@ -34,7 +34,7 @@ class Bot:
 		The command prefix for the bot.	
 	"""
 	def __init__(self, command_prefix : str = None, intents : int = 0, token : str = None):
-		self.http = HTTPClient(self)
+		self.http = HTTPClient(token)
 		self.token = token
 		self.intents = intents
 		self.command_prefix = command_prefix
@@ -49,8 +49,4 @@ class Bot:
 		try:
 			payload = Gateway().connect(str(self.token), self.intents)
 		except Exception as e:
-			raise InvokeError(e)		
-			
-bot = Bot(token="Nzg0MTIyMDYxMjE5OTU0NzA4.X8kskw.am004HyFPl2-uwqYioGcCC2ye_s", intents=Intents().all())
-
-bot.run()																								
\ No newline at end of file
+			raise InvokeError(e)																									
\ No newline at end of file
